#!/usr/bin/python

import yospaceCDS
import logging
logging.basicConfig(level=logging.INFO)
logging.getLogger('suds.client').setLevel(logging.DEBUG)

print "Live:-"
print yospaceCDS._ContentClient

#yospaceCDS.buildConnections("cds1.stg.yospace.com")
#
#print "Staging:-"
#print yospaceCDS._ContentClient




#!/usr/bin/python

import ws
import time

# The names this package exports
__all__ = [
# WebService Proxies
	'ContentService',
	'MediaItemService',
# Simple Helper Functions
	'CreateMediaItem',
	'StatusMediaItem',
	'DeleteMediaItem',
	'GetMediaItems',
# MediaItem Status values
	'MEDIAITEM_INVALID',
	'MEDIAITEM_VALID',
	'MEDIAITEM_UNKNOWN',
]

MEDIAITEM_INVALID = 0
MEDIAITEM_VALID = 1
MEDIAITEM_UNKNOWN = 2

def buildConnections(
	CDSDOMAIN="cds1.yospace.com", _https=True):
	"""Build SOAP objects to talk to yospaceCDS

	The main use for this is to switch to a staging or QA environment for testing. These facilities are not available outside Yospace so this function should never really be called by end users.
	"""
	global _ContentClient, ContentService, _MediaItemClient, MediaItemService
	ws.CDSDOMAIN = CDSDOMAIN
	_ContentClient = ws.ContentService(_https=_https)
	ContentService = _ContentClient.service
	_MediaItemClient = ws.MediaItemService(_https=_https)
	MediaItemService = _MediaItemClient.service

# Quick helper functions - MediaItemService
def CreateMediaItem(
	username,
	password,
	ContentURL,
	ContentGroupID,
	HQ=False,
	LargeFormat=None,
	MIMEType=None,
	RSSPublishDate=None,
	RSSItemTitle=None,
	RSSItemDescription=None,
	RSSTeaserText=None,
	ThumbnailURL=None,
	UsageProfileID=None,
	CuePoints=None,
	StatusCallbackURL=None,
	MD5Checksum=None,
	**_params):
	"""Creating a MediaItem

	All MediaItem object must belong to a Content Group.  If you are intending to use yospaceCDS as an unstructured store, then you simply need to create a single Content Group in your account and assign all MediaItems to that.  There is no limit to the number of MediaItem objects that can exist within a Content Group.

	However, if you would like to output items from yospaceCDS within feeds, then you will need to create the Content Groups you need, and assign these to the appropriate Output Feeds.  More information can be found on our chapters covering Content Groups and Output Feeds.

	To create a MediaItem within yospaceCDS the following parameters are supported:

Account Name / Password

URL to Asset to Upload
	an internet accessible URL of the video content.  Supported video formats are described in our Quick Start Guide.

Content Group ID
	you must create at least one Content Group within the yospaceCDS Content Management interface and use this ID.

HQ Processing Required
	specify true or false depending on whether you want H.264 processing on your video content. H.264 processing improves the quality of video for modern SmartPhone devices.

Large Format Required (optional)
	specify true or false depending on whether you want the video available in a large format suitable for the iPad. This option makes the content available in 640x360 (or 512x384 for 4:3) subject to the source content being available in the same or higher resolution.  This parameter is optional, and defaults to false if not supplied.

MIME type (optional)
	the MIME type of the uploaded content (if different from the MIME type given by the server)

RSS Publish Date
	the publishDate of the video (used for RSS output feeds to determine ordering).  If you do not set this, the time and date of ingestion is used instead. [

	Dates are specified in the format as determined by xsd:dateTime which follows the form defined by Chapter 5.4 in ISO 8601, which is:

	[-]CCYY-MM-DDThh:mm:ss[Z|(+|-)hh:mm]

	The time zone may be specified as Z (UTC) or (+|-)hh:mm. Time zones that aren't specified are considered undetermined.

	Example valid timestamps are:

		* 2009-10-26T21:32:52
		* 2009-10-26T21:32:52+02:00
		* 2009-10-26T19:32:52Z
		* 2009-10-26T19:32:52+00:00

RSS Item Title (optional)
	the title of the video, as shown in an RSS Feed or on the User Choice Page

RSS Item Description (optional)
	the description of the video, as shown in an RSS Feed or on the User Choice Page

RSS Teaser Text (optional)

Thumbnail URL (optional)
	a URL of a thumbnail image that will be associated with the video within an RSS Feed.  If you do not set this and publish this item via an RSS Feed, a default thumbnail grabbed from a few seconds into the video will be used instead.

Usage Profile ID - (optional)
	the ID of the Usage Profile using this parameter. You will need to obtain the ID of your Usage Profile from Yospace Support.

Cue Points - (optional)
	a comma separated list of cue points (defined as floating point numbers in seconds). For example:

	23.4,102.3,201.42

yospaceCDS will ingest the content and make cut points at the specified times in the video. These cut points can then be used for mid-roll dynamic insertion of advertising.

Status Update Callback - (optional)
	the URL to use for status callbacks. If omitted, no callbacks are made.

MD5 checksum - (optional)
	yospaceCDS will compute an MD5 checksum of the content it acquires and compare this against this parameter, if it supplied. If the checksums do not match, the content ingestion fails.


The return value is the MediaItem ID
	"""
	_params['username'] = username
	_params['password'] = password
	_params['contentUrl'] = ContentURL
	_params['contentGroupId'] = ContentGroupID
	_params['hq'] = HQ
	if LargeFormat != None:
		_params['largeFormat'] = LargeFormat
	if MIMEType != None:
		_params['mimeType'] = MIMEType
	if RSSPublishDate != None:
		_params['rssPubDate'] = RSSPublishDate
	if RSSItemTitle != None:
		_params['rssTitle'] = RSSItemTitle
	if RSSItemDescription != None:
		_params['rssItemDescription'] = RSSItemDescription
	if RSSTeaserText != None:
		_params['rssTeaserText'] = RSSTeaserText
	if ThumbnailURL != None:
		_params['thumbnailUrl'] = ThumbnailURL
	if UsageProfileID != None:
		_params['usageProfileID'] = UsageProfileID
	if CuePoints != None:
		_params['cuePoints'] = CuePoints
	if StatusCallbackURL != None:
		_params['stateChangeUrl'] = StatusCallbackURL
	if MD5Checksum != None:
		_params['checksum'] = MD5Checksum
	_response = MediaItemService.createMediaItem(**_params)
	if _response.statusCode != 200:
		raise Exception("CDS Exception: %s: %s" % (_response.statusCode, _response.statusDescription))
	return _response.mediaItemId

def StatusMediaItem(
	username,
	password,
	MediaItemID,
	**_params
	):
	"""Checking MediaItem Status

A MediaItem object will not be immediately available for end-users after creating it. yospaceCDS must perform intermediate processing work on the clip before it is available. In order to determine whether the clip is ready for end-user access, you can check it status using the statusMediaItemRequest call.

It requires:

Account Name / Password
MediaItem ID
	The ID that you will have received from a successful MediaItem creation.


The return value is a tuple of state code (From the table below) and a descriptive word
State Code      State Description
	0           Invalid (The processing failed)
	1           Valud (Ready for use)
	2           Unknown (Processing is currently in progress)
	"""
	_params['username'] = username
	_params['password'] = password
	_params['mediaItemId'] = MediaItemID
	_response = MediaItemService.statusMediaItem(**_params)
	if _response.statusCode != 200:
		raise Exception("CDS Exception: %s: %s" % (_response.statusCode, _response.statusDescription))
	return (int(_response.mediaItemStateCode), _response.mediaItemStateDescription)

def DeleteMediaItem(
	username,
	password,
	MediaItemID,
	**_params):
	"""MediaItem Deletion

If you no longer need a MediaItem object, it is necessary to delete it using the deleteMediaItemRequest method.

The call requires:

Account Name / Password
MediaItem ID
	The ID that you will have received from a successful MediaItem creation

There is no return value
	"""
	_params['username'] = username
	_params['password'] = password
	_params['mediaItemId'] = MediaItemID
	_response = MediaItemService.deleteMediaItem(**_params)
	if _response.statusCode != 200:
		raise Exception("CDS Exception: %s: %s" % (_response.statusCode, _response.statusDescription))
	return True

def GetMediaItems(
	username,
	password,
	ContentGroupID,
	**_params):
	"""List all media items in a content group

Account Name / Password

Content Group ID
	you must create at least one Content Group within the yospaceCDS Content Management interface and use this ID.

The return is a list of dictionaries, each describing one media item in the content group, for example:
[
	{
		id = 1234,
		stateCode = 1,							# 0 == Invalid, 1 == Valid, 2 == Still Processing
		stateDescription = "VALID",
		title = "My Media Item Title",
		createDate = 1282911308.0				# Time when item was created in Epoch Time
	},
	...
	...
]
	"""
	_params['username'] = username
	_params['password'] = password
	_params['contentGroupId'] = ContentGroupID
	_response = MediaItemService.getMediaItems(**_params)
	if _response.statusCode != 200:
		raise Exception("CDS Exception: %s: %s" % (_response.statusCode, _response.statusDescription))
	if not hasattr(_response, 'mediaItemDetails'):
		return []
	return [
		{
			"id": item.id,
			"stateCode": item.stateCode,
			"stateDescription": item.stateDescription,
			"title": item.title,
			"createDate": time.mktime(item.createDate.utctimetuple()),
		} for item in _response.mediaItemDetails
	]

def ReingestMedia(
	username,
	password,
	ContentURL,
	mediaItemID,
	HQ=False,
	LargeFormat=None,
	MIMEType=None,
	UsageProfileID=None,
	CuePoints=None,
	StatusCallbackURL=None,
	MD5Checksum=None,
	**_params):
	"""Replacing the video content of a MediaItem

The return value is True if the request was accepted, an exception is thrown otherwise.
	"""
	_params['username'] = username
	_params['password'] = password
	_params['contentUrl'] = ContentURL
	_params['contentGroupId'] = ContentGroupID
	_params['mobileHq'] = HQ
	if LargeFormat != None:
		_params['mobileLargeFormat'] = LargeFormat
	if MIMEType != None:
		_params['mimeType'] = MIMEType
	_response = MediaItemService.reingestMedia(**_params)
	if _response.statusCode != 200:
		raise Exception("CDS Exception: %s: %s" % (_response.statusCode, _response.statusDescription))
	return True
#	return _response.mediaItemId



#!/usr/bin/python

import yospaceCDS
import logging
logging.basicConfig(level=logging.INFO)
logging.getLogger('suds.client').setLevel(logging.DEBUG)

yospaceCDS.buildConnections("cds1.yospace.com")

print yospaceCDS._MediaItemClient

#print yospaceCDS.CreateMediaItem("yospace01", "myflow", "http://qa.broadcastcdn.reuters.com/testdata/T999-UK-Test.mpg", 12210221, True, True, 'video/mpg', 'Regression Test Video', 'Regresion test video for the media item API', '', 1289819499.0)
print yospaceCDS.GetMediaItems("yospace01", "myflow", 12210221)
#print yospaceCDS.deleteMediaItem("yospace01", "myflow", 12210221)
#print yospaceCDS.StatusMediaItem("yospace01", "myflow", 12210312)



#!/usr/bin/python

import suds.client

# Which Yospace CDS platform should be targetted?
CDSDOMAIN = "cds1.yospace.com"

#-- "Abstract" WebService Client Class ----------------------------------------

class _ws(suds.client.Client):
	"Convenience class for CDS Web Services, based on the WSDL"

	SERVICEADDRESS = "set_this_to_a_service_address"

	def __init__(self, service=None, faults=True):
		"Connect to the service and remember the un/pw"
		# Set the service address
		if service:
			self.SERVICEADDRESS = service
		# Initialise the SOAP sub-system, including loading the WSDL
		suds.client.Client.__init__(
			self,
			self.SERVICEADDRESS,
			faults=faults,
		)

#-- Content Service -----------------------------------------------------------

class ContentService(_ws):
	"CDS ContentService Client"
	def __init__(self, service=None, faults=True, _https=True):
		if _https:
			self.SERVICEADDRESS = "https://%s/cds-controller/contentService?wsdl" % (CDSDOMAIN, )
		else:
			self.SERVICEADDRESS = "http://%s/cds-controller/contentService?wsdl" % (CDSDOMAIN, )
		_ws.__init__(
			self,
			service=service,
			faults=faults,
		)

#-- Media Item Service --------------------------------------------------------

class MediaItemService(_ws):
	"CDS ContentService Client"
	def __init__(self, service=None, faults=True, _https=True):
		if _https:
			self.SERVICEADDRESS = "https://%s/mediaitemmanager/manage?wsdl" % (CDSDOMAIN, )
		else:
			self.SERVICEADDRESS = "http://%s/mediaitemmanager/manage?wsdl" % (CDSDOMAIN, )
		_ws.__init__(
			self,
			service=service,
			faults=faults,
		)

if __name__ == '__main__':
# Simple testing
	cs = ContentService()
	print cs

	mis = MediaItemService()
	print mis



#!/usr/bin/env python

from setuptools import setup

setup(
	name='yospaceCDS',
	version='1.1.0',
	description='Yospace CDS Webservice Client',
	long_description='''A simple library providing access to the yospaceCDS video transcoding and
mobile delivery services.

yospaceCDS is underpinned by a powerful and extensible storage and transcoding
system that is now available to integrate into your own video production
workflow or internet/mobile video application.  The service allows you to
upload video content of practically any format and order it to be transcoded
into a wealth of different popular formats for web and mobile consumption.
You can also order content to be forwarded to an FTP server for syndication
purposes. With this library you integrate with yospaceCDS using a simple set
of Web Services APIs to give you absolute control of your transcoding and
storage requirements.

Usage example:

import yospaceCDS

yospaceCDS.buildConnections()
mediaItemID = yospaceCDS.CreateMediaItem(
	"yospace_account",
	"yospace_secret",
	"http://server.name/video.mp4",
	12345678
)
# "yospace_account" is your login name to yospaceCDS
# "yospace_password" is your yospaceCDS password
# 12345678 is the Content Group in your yospaceCDS account


For more information, or to request a trial account, please visit our website.''',
	author='Yospace Systems',
	license='Distribute Freely',
	author_email='systems@yospace.com',
	url='http://www.yospace.com/index.php/cds_main.html',
	packages=['yospaceCDS'],
	classifiers=[
		"Development Status :: 5 - Production/Stable",
		"Intended Audience :: Developers",
		"License :: Freely Distributable",
		"Operating System :: Unix",
		"Operating System :: POSIX :: Linux",
		"Operating System :: POSIX :: SunOS/Solaris",
		"Operating System :: Microsoft",
		"Operating System :: Microsoft :: Windows",
		"Operating System :: MacOS",
		"Programming Language :: Python",
		"Topic :: Multimedia :: Video :: Conversion",
		"Topic :: Software Development :: Libraries :: Python Modules",
	],
	install_requires=[
		"suds >= 0.4",
	],
)
